thread_init

Function thread_init 

pub fn thread_init()
Initialize LIKWID’s marker API for the current thread

Must be called in parallel region of the application to set up basic data structures of LIKWID. Before you can call likwid_markerThreadInit() you have to call likwid_markerInit().